<template>
  <ModalDialog
    ref="createModal"
    is-page
    size="2xl"
    @close="$router.push({ name: 'links' })"
  >
    <ModalHeader>
      <ModalTitle>{{ $t("app.links.create.title") }}</ModalTitle>
    </ModalHeader>
    <ModalForm @submit="submit">
      <template #default>
        <AlertError v-if="form.errors && form.errors?.unknown">
          {{ form.errors.unknown }}
        </AlertError>
        <FormInput
          id="url"
          :errors="form.errors.url"
        >
          <FormLabel>{{ $t("app.links.form.url") }}</FormLabel>
          <FormText
            v-model="form.values.url"
            name="url"
            type="url"
            required
          />
        </FormInput>
        <LinksOptionsForm
          v-model="form.values"
          :errors="form.errors"
        />
      </template>
      <template #footer>
        <FormSubmit
          :processing="form.isFetching"
          class="btn btn-black"
        >
          {{ $t("app.links.create.submit") }}
        </FormSubmit>
      </template>
    </ModalForm>
  </ModalDialog>
</template>

<script lang="ts" setup>
import ModalTitle from "@/js/contexts/shared/ui/components/modal/ModalTitle.vue";
import ModalHeader from "@/js/contexts/shared/ui/components/modal/ModalHeader.vue";
import ModalDialog from "@/js/contexts/shared/ui/components/modal/ModalDialog.vue";
import ModalForm from "@/js/contexts/shared/ui/components/modal/ModalForm.vue";
import AlertError from "@/js/contexts/shared/ui/components/alert/AlertError.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormSubmit from "@/js/contexts/form/ui/components/FormSubmit.vue";
import useForm from "@/js/contexts/shared/composables/useForm";
import useModal from "@/js/contexts/shared/composables/useModal";
import useNotification from "@/js/contexts/shared/composables/useNotification";
import type { LinkCreate } from "@/js/contexts/shared/models/Link";
import LinksOptionsForm from "@/js/contexts/links/ui/components/LinksOptionsForm.vue";

const emit = defineEmits<{
  fetch: [];
}>();

const { t } = useI18n();
const { successNotification } = useNotification();
const createModal = ref<InstanceType<typeof ModalDialog>>();
const modal = useModal(createModal);
const form = useForm<LinkCreate>({
  url: "",
});

const submit = () => {
  form.post("/api/links", {
    onSuccess: () => {
      emit("fetch");
      modal.close();
      successNotification(t("app.links.create.success"));
    },
  });
};
</script>
